pub struct BatchPrepareCache { /* private fields */ }Expand description
Cached state created when batch preparing a group of blocks.
This cache is only valid for the set of blocks it was created with, it should not be used for other blocks.