pub struct PreparedBlock {
pub block: Block,
pub block_blob: Vec<u8>,
pub hf_vote: HardFork,
pub hf_version: HardFork,
pub block_hash: [u8; 32],
pub pow_hash: [u8; 32],
pub miner_tx_weight: usize,
}Expand description
A pre-prepared block with all data needed to verify it.
Fields
block: BlockThe block
block_blob: Vec<u8>The serialised block’s bytes
hf_vote: HardForkThe block’s hf vote
hf_version: HardForkThe block’s hf version
block_hash: [u8; 32]The block’s hash
pow_hash: [u8; 32]The block’s POW hash.
miner_tx_weight: usizeThe weight of the block’s miner transaction.
Implementations
Sourceimpl PreparedBlock
impl PreparedBlock
Sourcepub fn new<R: RandomX>(
block: Block,
randomx_vm: Option<&R>,
) -> Result<Self, ConsensusError>
pub fn new<R: RandomX>( block: Block, randomx_vm: Option<&R>, ) -> Result<Self, ConsensusError>
Creates a new PreparedBlock.
The randomX VM must be Some if RX is needed or this will panic. The randomX VM must also be initialised with the correct seed.
Sourcepub fn new_alt_block(block: AltBlockInformation) -> Result<Self, ConsensusError>
pub fn new_alt_block(block: AltBlockInformation) -> Result<Self, ConsensusError>
Creates a new PreparedBlock from an AltBlockInformation.